# Summ

[![PyPI - Version](https://img.shields.io/pypi/v/summ.svg)](https://pypi.org/project/summ)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/summ.svg)](https://pypi.org/project/summ)

-----

Summ is an open-source product that utilizes ChatGPT to provide intelligent question-answering and search capabilities across user transcripts. It allows users to easily surface insights and summarize facts across various dimensions such as department, industry, and role. With the help of natural language processing, the tool can understand and respond to complex questions and queries, making it easy for users to find the information they need.

**Table of Contents**

- [Summ](#summ)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install summ
```

## License

`summ` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
